@@ -6,29 +6,29 @@ if TYPE_CHECKING:
     from aasm.intermediate.argument import Argument
 
 
-class Declaration:  
+class Declaration:
     def __init__(self, name: Argument, value: Argument):
         self.name: str = name.expr
         self.value: Argument = value
-        
+
     def print(self) -> None:
-        print(f'Declaration: {self.name}')
+        print(f"Declaration: {self.name}")
         self.value.print()
 
 
-class FloatDeclaration(Declaration):  
+class FloatDeclaration(Declaration):
     def __init__(self, name: Argument, value: Argument):
         super().__init__(name=name, value=value)
-        
+
     def print(self) -> None:
-        print(f'FloatDeclaration: {self.name}')
+        print(f"FloatDeclaration: {self.name}")
         super().print()
 
 
 class ConnectionDeclaration(Declaration):
     def __init__(self, name: Argument, value: Argument):
         super().__init__(name=name, value=value)
-        
+
     def print(self) -> None:
-        print(f'ConnectionDeclaration: {self.name}')
+        print(f"ConnectionDeclaration: {self.name}")
         super().print()
